@@ -41,10 +41,12 @@
 #include "comp_bitsums.h"
 #include "comp_textrle.h"
 #endif
-#include "comp_range.h"
 #include "comp_snibble.h"
 #include "comp_text.h"
 #include "comp_fail.h"
+#include "comp_lzoox.h"
+#include "comp_lzooy.h"
+#include "comp_lzota.h"
 
 #ifdef __DACT_C
 int (*(algorithms[256]))()={    comp_plain_algo,
@@ -79,7 +81,10 @@ int (*(algorithms[256]))()={    comp_plain_algo,
 				DACT_FAILED_ALGO,
 				DACT_FAILED_ALGO,
 #endif
-				NULL, NULL, NULL, NULL, NULL, NULL, NULL,
+				comp_lzoox_algo,
+				comp_lzooy_algo,
+				comp_lzota_algo,
+				NULL, NULL, NULL, NULL, NULL,
 				NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL,
 				NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL,
 				NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL,
@@ -143,6 +148,15 @@ char *algorithm_names[256]={	"Uncompressed",
 				"Unsupported Algorithm (factor)",
 				"Unsupported Algorithm (bitsums)",
 				"Unsupported Algorithm (textrle)",
+#endif
+#ifdef HAVE_LIBLZO
+				"LZO-1x Compression",
+				"LZO-1y Compression",
+				"LZO-2a Compression",
+#else
+				"Unsupported Algorithm (comp_lzoox)",
+				"Unsupported Algorithm (comp_lzooy)",
+				"Unsupported Algorithm (comp_lzota)",
 #endif
 				NULL
 			};
