@@ -22,9 +22,16 @@
 #define _CIPHER_PSUB_H
 #include "dact.h"
 
+#if defined(USE_MODULES) && !defined(AS_MODULE)
+#define cipher_psub DACT_FAILED_ALGO
+#else
+
+
 int cipher_psub(const unsigned char *inblock, unsigned char *outblock, const int blksize, unsigned char *key, const int mode);
 int cipher_psub_init(const int mode, unsigned char *key);
 int cipher_psub_init_getkey(const int mode, unsigned char *key);
+char *cipher_psub_generatekey(const char *passphrase);
 int cipher_psub_encrypt(const unsigned char *inblk, unsigned char *outblk, int blksize, unsigned char *key);
 int cipher_psub_decrypt(const unsigned char *inblk, unsigned char *outblk, int blksize, unsigned char *key);
 #endif
+#endif
