@@ -21,6 +21,12 @@
 #ifndef _CIPHER_SUB_H
 #define _CIPHER_SUB_H
 #include "dact.h"
+#include "comp_fail.h"
+
+#if defined(USE_MODULES) && !defined(AS_MODULE)
+#define cipher_sub DACT_FAILED_ALGO
+#else
+
 
 int cipher_sub(const char *inblock, char *outblock, const int blksize, char *key, const int mode);
 int cipher_sub_init(const int mode, char *key);
@@ -30,3 +36,4 @@ int cipher_sub_decrypt(const unsigned char *inblk, unsigned char *outblk, int bl
 char *generatekey(void);
 
 #endif
+#endif
