@@ -29,8 +29,12 @@
 #include "dact.h"
 #include "comp_fail.h"
 #include <stdio.h>
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
+#endif
+#ifdef HAVE_STDLIB_H
 #include <stdlib.h>
+#endif
 
 
 /*
