@@ -23,9 +23,15 @@
 #include "comp_text.h"
 #include "buffer.h"
 #include <stdio.h>
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
+#endif
+#ifdef HAVE_STDLIB_H
 #include <stdlib.h>
+#endif
+#ifdef HAVE_STRING_H
 #include <string.h>
+#endif
 
 
 /*
@@ -38,7 +44,9 @@
 */
 
 #if defined(USE_MODULES) && defined(AS_MODULE)
-int DC_NUM=3;
+#include "module.h"
+uint32_t DC_NUM=3;
+uint32_t DC_TYPE=DACT_MOD_TYPE_COMP;
 void *DC_ALGO=comp_text_algo;
 char *DC_NAME="Text Compression (MOD)";
 #endif
