@@ -18,11 +18,15 @@
  *      email: dact@rkeene.org
  */
 
-#include <stdlib.h>
-#include <stdio.h>
-#include <string.h>
-#include "header.h"
 #include "dact.h"
+#ifdef HAVE_STDLIB_H
+#include <stdlib.h>
+#endif
+#include <stdio.h>
+#ifdef HAVE_STRING_H
+#include <string.h>
+#endif
+#include "header.h"
 
 char *dact_hdr_ext_val=NULL;
 uint32_t dact_hdr_ext_sze=0;
