@@ -48,7 +48,6 @@
 #include "parse.h"
 #include "crc.h"
 
-extern int errno;
 struct dact_url_info {
 	char *url;
 	int flags;
@@ -109,21 +108,12 @@ int createconnection_tcp(char *host, int port) {
 	return(sockid);
 }
 
-int open_net(const char *pathname, int flags, ...) {
+int open_net(const char *pathname, int flags, mode_t mode) {
 	char scheme[5], host[512], file[1024];
 	char username[128], password[128];
 	char *read_buf, *read_buf_s=NULL;
 	char *smallbuf, *tmpbuf;
 	int port, fd, x, ftpfd=-1, retrmode=0;
-	va_list args;
-	mode_t mode;
-
-        if (flags==O_WRONLY || flags==O_RDWR) {
-		va_start(args, flags);
-		/* This *SHOULD* be `int' here, not mode_t, for some reason. */
-		mode = va_arg(args, int);
-		va_end(args);
-	}
 
 	if (!parse_url(pathname,scheme,username,password,host,&port,file)) {
 		if ((fd=createconnection_tcp(host,port))<0) return(-1);
@@ -159,8 +149,7 @@ int open_net(const char *pathname, int flags, ...) {
 				if (strncmp("200 ",read_buf,4) && strncmp("302 ",read_buf,4)) {
 					free(read_buf_s);
 					close(fd);
-					errno=ENOENT;
-					return(-1);
+					return(-ENOENT);
 				}
 				retrmode=read_buf[0];
 				read_buf=read_buf_s;
@@ -202,8 +191,7 @@ int open_net(const char *pathname, int flags, ...) {
 					if ((x=read(fd, read_buf, 1024))<1024) {
 						if (x<0) {
 							free(read_buf_s);
-							errno=EIO;
-							return(-1);
+							return(-EIO);
 						}
 						/* It's waiting for input... */
 					}
@@ -215,22 +203,19 @@ int open_net(const char *pathname, int flags, ...) {
 								if (ftpfd!=-1) close(ftpfd);
 								close(fd);
 								free(read_buf_s);
-								errno=ENOENT;
-								return(-1);
+								return(-ENOENT);
 								break;
 							case 230944: /* 530 */
 								if (ftpfd!=-1) close(ftpfd);
 								close(fd);
 								free(read_buf_s);
-								errno=EIO;
-								return(-1);
+								return(-EIO);
 								break;
 							case 231504: /* 553 */
 								if (ftpfd!=-1) close(ftpfd);
 								close(fd);
 								free(read_buf_s);
-								errno=EPERM;
-								return(-1);
+								return(-EPERM);
 								break;
 							case 218400: /* 220 */
 								write(fd, "USER ", 5);
@@ -268,8 +253,7 @@ int open_net(const char *pathname, int flags, ...) {
 								write(fd, "\n", 1);
 								if ((ftpfd=createconnection_tcp(host,port))<0) {
 									close(fd);
-									errno=ENOENT;
-									return(-1);
+									return(-ENOENT);
 								}
 								break;
 							case 215072: /* 150 */ 
