@@ -31,6 +31,6 @@
 int createlisten(int port);
 void closeconnection(int sockfd);
 int createconnection_tcp(char *host, int port);
-int open_net(const char *pathname, int flags, ...);
+int open_net(const char *pathname, int flags, mode_t mode);
 off_t lseek_net(int filedes, off_t offset, int whence);
 #endif
