@@ -21,8 +21,12 @@
 
 #include "dact.h"
 #include "sort.h"
+#ifdef HAVE_STDLIB_H
 #include <stdlib.h>
+#endif
+#ifdef HAVE_STRING_H
 #include <string.h>
+#endif
 #include <stdio.h>
 
 
