@@ -25,12 +25,18 @@
  *
  */
 
-#include <stdlib.h>
-#include <string.h>
-#include <unistd.h>
-#include <stdio.h>
 #include "dact.h"
 #include "ui.h"
+#ifdef HAVE_STDLIB_H
+#include <stdlib.h>
+#endif
+#ifdef HAVE_STRING_H
+#include <string.h>
+#endif
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>
+#endif
+#include <stdio.h>
 
 char dact_ui_statusvar[128];
 
@@ -114,7 +120,7 @@ void dact_ui_incrblkcnt(int n) {
 }
 
 int32_t dact_ui_optmanip(int action, int opt, int32_t val) {
-	static int opts[4]={0,0,0,0};
+	static int opts[10]={0,0,0,0,0,0,0,0,0};
 
 	if (opt>=(sizeof(opts)/sizeof(int))) return(-1);
 
@@ -156,20 +162,25 @@ void dact_ui_setup(uint32_t blocks) {
 
 char *dact_ui_getuserinput(char *prompt, unsigned int n, int password) {
 	char *ret;
+	FILE *fd;
 
 	if (password) {
 		if (n<128) return(NULL);
 		ret=getpass(prompt);
 		return(ret);
-	} else {
-		if ((ret=malloc(n+1))==NULL) return(NULL);
-		fprintf(stderr, "%s", prompt);
-		fflush(stderr);
-		fgets(ret, n, stdin);
-		ret=strsep(&ret, "\n\r");
-		return(ret);
 	}
-	return(NULL); /* To make gcc happy. */
+	if (dact_ui_getopt(DACT_UI_OPT_PASSSTDIN)==1) {
+		fd=stdin;
+	} else {
+		fd=fopen("/dev/tty", "r");
+	}
+	if ((ret=malloc(n))==NULL) return(NULL);
+	fprintf(stderr, "%s", prompt);
+	fflush(stderr);
+	fgets(ret, n, fd);
+	ret=strsep(&ret, "\n\r");
+	if (fd!=stdin) fclose(fd);
+	return(ret);
 }
 
 
